@@ -1,14 +1,13 @@
 package Pod::Weaver::Plugin::Eval;
 
+our $DATE = '2016-10-14'; # DATE
+our $VERSION = '0.03'; # VERSION
+
 use 5.010001;
 use Moose;
 with 'Pod::Weaver::Role::Section';
 
 use List::Util qw(first);
-use Pod::Elemental;
-use Pod::Elemental::Element::Nested;
-
-our $VERSION = '0.02'; # VERSION
 
 # regex
 has include_modules => (
@@ -91,23 +90,25 @@ sub weave_section {
 }
 
 1;
-# ABSTRACT: Evaluate code
-
+# ABSTRACT: (DEPRECATED) Evaluate code
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Pod::Weaver::Plugin::Eval - Evaluate code
+Pod::Weaver::Plugin::Eval - (DEPRECATED) Evaluate code
 
 =head1 VERSION
 
-version 0.02
+This document describes version 0.03 of Pod::Weaver::Plugin::Eval (from Perl distribution Pod-Weaver-Plugin-Eval), released on 2016-10-14.
 
 =head1 SYNOPSIS
 
-In your C<weaver.ini>:
+In your F<weaver.ini>:
 
  [-Eval]
  include_modules = ^Foo::Bar$
@@ -116,6 +117,9 @@ In your C<weaver.ini>:
 
 =head1 DESCRIPTION
 
+B<DEPRECATION NOTICE:> This module is deprecated in favor of
+L<Pod::Weaver::Plugin::Run>.
+
 This plugin evaluates Perl code specified in your weaver.ini (or dist.ini). It
 can be used to do various stuffs that might be too trivial/short to build a
 dedicated Pod::Weaver::Plugin for.
@@ -178,20 +182,37 @@ input (original) document. Can also be retrieved from C<args>.
 
 =back
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver-Plugin-Eval>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Pod-Weaver-Plugin-Eval>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Pod-Weaver-Plugin-Eval>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 SEE ALSO
 
 L<Pod::Weaver>
 
+L<Pod::Weaver::Plugin::Run>
+
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
